@@ -1,5 +1,7 @@
 #!/usr/bin/env perl
 
+# Select brewer palette to use
+
 use 5.016;
 use warnings;
 
@@ -18,7 +20,7 @@ my $p = ggplot(
     data    => $dsamp,
     mapping => aes( x => 'carat', y => 'price' )
 )->geom_point( mapping => aes( color => 'clarity' ) )
- ->scale_color_brewer();
+ ->scale_color_brewer( palette => 'Greens' );
 
 if (defined $save_as) {
     $p->save($save_as);
