@@ -4,7 +4,7 @@ package Chart::GGPlot;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.002000'; # VERSION
+our $VERSION = '0.002001'; # VERSION
 
 use Data::Munge qw(elem);
 use Data::Frame::Types qw(DataFrame);
@@ -134,7 +134,7 @@ Chart::GGPlot - ggplot2 port in Perl
 
 =head1 VERSION
 
-version 0.002000
+version 0.002001
 
 =head1 STATUS
 
@@ -276,9 +276,15 @@ L<Data::Frame>
 
 Stephan Loyd <sloyd@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Pablo Rodríguez (pablrod)
+
+Pablo Rodríguez (pablrod)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2021 by Stephan Loyd.
+This software is copyright (c) 2019-2022 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
