@@ -7,7 +7,7 @@ package Chart::GGPlot::Util::Scales;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.002000'; # VERSION
+our $VERSION = '0.002001'; # VERSION
 
 use Color::Brewer;
 use Color::Library;
@@ -709,7 +709,7 @@ fun pretty_dt($x, :$n = 5, :$min_n = $n % 2, %rest) {
             unless ( $nat->where( $nat > $at->at(-1) )->length == $nat->length ) {    # failed
                 $r2 = $at->length - 1;
             }
-            $at = $at->glue( 0, $nat );
+            $at = PDL::DateTime->new( $at->glue( 0, $nat ) );
         }
         return $at->slice( pdl( [ $r1 .. $r2 ] ) );
     };
@@ -941,7 +941,7 @@ Chart::GGPlot::Util::Scales - R 'scales' package functions used by Chart::GGPlot
 
 =head1 VERSION
 
-version 0.002000
+version 0.002001
 
 =head1 FUNCTIONS
 
@@ -1014,7 +1014,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2021 by Stephan Loyd.
+This software is copyright (c) 2019-2022 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
